@@ -25,15 +25,14 @@ from typing import List
 import click
 import rasterio.crs as rio_crs
 from click.core import ParameterSource
-from rasterio.dtypes import dtype_ranges
-from rasterio.errors import CRSError
-
 from geedim import schema, Initialize, version
 from geedim.collection import MaskedCollection
 from geedim.download import BaseImage
 from geedim.enums import CloudMaskMethod, CompositeMethod, ResamplingMethod
 from geedim.mask import MaskedImage
 from geedim.utils import get_bounds, Spinner
+from rasterio.dtypes import dtype_ranges
+from rasterio.errors import CRSError
 
 logger = logging.getLogger(__name__)
 
@@ -227,6 +226,10 @@ resampling_option = click.option(
     default=BaseImage._default_resampling.value, show_default=True, callback=_resampling_method_cb,
     help='Resampling method.'
 )
+scale_offset_option = click.option(
+    '-so/-nso', '--scale-offset/--no-scale-offset', default=False, show_default=True,
+    help='Whether to apply any EE band scales and offsets to the image.'
+)
 
 
 # geedim CLI and chained command group
@@ -260,7 +263,7 @@ def cli(ctx, verbose, quiet):
     '-mm', '--mask-method', type=click.Choice([cmm.value for cmm in CloudMaskMethod], case_sensitive=True),
     default=CloudMaskMethod.cloud_prob.value, show_default=True, callback=_mask_method_cb,
     help='Method used to mask clouds.  Valid for Sentinel-2 images. '
-)  # TODO: add an explanation for these options
+)
 @click.option(
     '-p', '--prob', type=click.FloatRange(min=0, max=100), default=60, show_default=True,
     help='Cloud probability threshold (%). Valid for Sentinel-2 images with the `cloud-prob` :option:`--mask-method`'
@@ -300,17 +303,19 @@ def config(ctx, mask_cirrus, mask_shadows, mask_method, prob, dark, shadow_dist,
     Cloud/shadow masking is supported for the collections:
     \b
 
-        ==============  ======================
-        geedim name     EE name
-        ==============  ======================
-        sentinel2-sr    COPERNICUS/S2_SR
-        sentinel2-toa   COPERNICUS/S2
-        landsat9-c2-l2  LANDSAT/LC09/C02/T1_L2
-        landsat8-c2-l2  LANDSAT/LC08/C02/T1_L2
-        landsat7-c2-l2  LANDSAT/LE07/C02/T1_L2
-        landsat5-c2-l2  LANDSAT/LT05/C02/T1_L2
-        landsat4-c2-l2  LANDSAT/LT04/C02/T1_L2
-        ==============  ======================
+        ===========  ===========================
+        geedim name  EE name
+        ===========  ===========================
+        l4-c2-l2     LANDSAT/LT04/C02/T1_L2
+        l5-c2-l2     LANDSAT/LT05/C02/T1_L2
+        l7-c2-l2     LANDSAT/LE07/C02/T1_L2
+        l8-c2-l2     LANDSAT/LC08/C02/T1_L2
+        l9-c2-l2     LANDSAT/LC09/C02/T1_L2
+        s2-toa       COPERNICUS/S2
+        s2-sr        COPERNICUS/S2_SR
+        s2-toa-hm    COPERNICUS/S2_HARMONIZED
+        s2-sr-hm     COPERNICUS/S2_SR_HARMONIZED
+        ===========  ===========================
     \b
 
     For Sentinel-2 collections, ``--mask-method`` can be one of:
@@ -325,13 +330,13 @@ def config(ctx, mask_cirrus, mask_shadows, mask_method, prob, dark, shadow_dist,
     --------
 
     Search the Sentinel-2 SR collection for images with a cloudless portion of at least 60%, where cloud/shadow is
-    identified with the `qa` ``mask-method`` ::
+    identified with the `qa` ``mask-method``::
 
-        $ geedim config --mask-method qa search -c sentinel2-sr --cloudless-portion 60 -s 2022-01-01 -e 2022-01-14 --bbox 24 -34 24.5 -33.5
+        geedim config --mask-method qa search -c s2-sr --cloudless-portion 60 -s 2022-01-01 -e 2022-01-14 --bbox 24 -34 24.5 -33.5
 
     Download and cloud/shadow mask a Landsat-8 image, where shadows are excluded from the mask::
 
-        $ geedim config --no-mask-shadows download -i LANDSAT/LC08/C02/T1_L2/LC08_172083_20220104 --mask --bbox 24.25 -34 24.5 -33.75
+        geedim config --no-mask-shadows download -i LANDSAT/LC08/C02/T1_L2/LC08_172083_20220104 --mask --bbox 24.25 -34 24.5 -33.75
     """
     # @formatter:on
     # store commandline configuration (only) in the context object for use by other commands
@@ -381,17 +386,19 @@ def search(obj, collection, start_date, end_date, bbox, region, fill_portion, cl
     collections:
     \b
 
-        ==============  ======================
-        geedim name     EE name
-        ==============  ======================
-        sentinel2-sr    COPERNICUS/S2_SR
-        sentinel2-toa   COPERNICUS/S2
-        landsat9-c2-l2  LANDSAT/LC09/C02/T1_L2
-        landsat8-c2-l2  LANDSAT/LC08/C02/T1_L2
-        landsat7-c2-l2  LANDSAT/LE07/C02/T1_L2
-        landsat5-c2-l2  LANDSAT/LT05/C02/T1_L2
-        landsat4-c2-l2  LANDSAT/LT04/C02/T1_L2
-        ==============  ======================
+        ===========  ===========================
+        geedim name  EE name
+        ===========  ===========================
+        l4-c2-l2     LANDSAT/LT04/C02/T1_L2
+        l5-c2-l2     LANDSAT/LT05/C02/T1_L2
+        l7-c2-l2     LANDSAT/LE07/C02/T1_L2
+        l8-c2-l2     LANDSAT/LC08/C02/T1_L2
+        l9-c2-l2     LANDSAT/LC09/C02/T1_L2
+        s2-toa       COPERNICUS/S2
+        s2-sr        COPERNICUS/S2_SR
+        s2-toa-hm    COPERNICUS/S2_HARMONIZED
+        s2-sr-hm     COPERNICUS/S2_SR_HARMONIZED
+        ===========  ===========================
 
     A search region must be specified with either the ``--bbox`` or ``--region`` option.
 
@@ -404,11 +411,11 @@ def search(obj, collection, start_date, end_date, bbox, region, fill_portion, cl
 
     Search the GEDI canopy height collection for images with a filled portion of at least 0.5%::
 
-        $ geedim search -c LARSE/GEDI/GEDI02_A_002_MONTHLY -s 2021-12-01 -e 2022-02-01 --bbox 23 -34 23.2 -33.8 --fill-portion 0.5
+        geedim search -c LARSE/GEDI/GEDI02_A_002_MONTHLY -s 2021-12-01 -e 2022-02-01 --bbox 23 -34 23.2 -33.8 --fill-portion 0.5
 
     Search the Landsat-9 collection for images with a cloud/shadow free portion of at least 50%::
 
-        $ geedim search -c landsat9-c2-l2 -s 2022-01-01 -e 2022-03-01 --bbox 23 -34 23.2 -33.8 --cloudless-portion 50
+        geedim search -c l9-c2-l2 -s 2022-01-01 -e 2022-03-01 --bbox 23 -34 23.2 -33.8 --cloudless-portion 50
     """
     # @formatter:on
     if not obj.region:
@@ -460,6 +467,7 @@ cli.add_command(search)
 @dtype_option
 @mask_option
 @resampling_option
+@scale_offset_option
 @click.option('-o', '--overwrite', is_flag=True, default=False, help='Overwrite the destination file if it exists.')
 @click.pass_obj
 def download(obj, image_id, bbox, region, download_dir, mask, overwrite, **kwargs):
@@ -503,11 +511,11 @@ def download(obj, image_id, bbox, region, download_dir, mask, overwrite, **kwarg
 
     Download a region of a Landsat-9 image, applying the cloud/shadow mask and converting to uint16::
 
-        $ geedim download -i LANDSAT/LC09/C02/T1_L2/LC09_173083_20220308 --mask --bbox 21.6 -33.5 21.7 -33.4 --dtype uint16
+        geedim download -i LANDSAT/LC09/C02/T1_L2/LC09_173083_20220308 --mask --bbox 21.6 -33.5 21.7 -33.4 --dtype uint16
 
     Download the results of a MODIS NBAR search, specifying a CRS and scale to reproject to::
 
-        $ geedim search -c MODIS/006/MCD43A4 -s 2022-01-01 -e 2022-01-03 --bbox 23 -34 24 -33 download --crs EPSG:3857 --scale 500
+        geedim search -c MODIS/006/MCD43A4 -s 2022-01-01 -e 2022-01-03 --bbox 23 -34 24 -33 download --crs EPSG:3857 --scale 500
     """
     # @formatter:on
     logger.info('\nDownloading:\n')
@@ -535,6 +543,7 @@ cli.add_command(download)
 @dtype_option
 @mask_option
 @resampling_option
+@scale_offset_option
 @click.option(
     '-w/-nw', '--wait/--no-wait', default=True, show_default=True, help='Whether to wait for the export to complete.'
 )
@@ -577,11 +586,11 @@ def export(obj, image_id, bbox, region, drive_folder, mask, wait, **kwargs):
 
     Export a region of a Landsat-9 image, applying the cloud/shadow mask and converting to uint16::
 
-        $ geedim export -i LANDSAT/LC09/C02/T1_L2/LC09_173083_20220308 --mask --bbox 21.6 -33.5 21.7 -33.4 --dtype uint16
+        geedim export -i LANDSAT/LC09/C02/T1_L2/LC09_173083_20220308 --mask --bbox 21.6 -33.5 21.7 -33.4 --dtype uint16
 
     Export the results of a MODIS NBAR search to the 'geedim' folder, specifying a CRS and scale to reproject to::
 
-        $ geedim search -c MODIS/006/MCD43A4 -s 2022-01-01 -e 2022-01-03 --bbox 23 -34 24 -33 export --crs EPSG:3857 --scale 500 -df geedim
+        geedim search -c MODIS/006/MCD43A4 -s 2022-01-01 -e 2022-01-03 --bbox 23 -34 24 -33 export --crs EPSG:3857 --scale 500 -df geedim
     """
     # @formatter:on
     logger.info('\nExporting:\n')
@@ -691,15 +700,15 @@ def composite(obj, image_id, mask, method, resampling, bbox, region, date):
     --------
     Composite two Landsat-7 images using the default options and download the result::
 
-        $ geedim composite -i LANDSAT/LE07/C02/T1_L2/LE07_173083_20100203 -i LANDSAT/LE07/C02/T1_L2/LE07_173083_20100219 download --bbox 22 -33.1 22.1 -33 --crs EPSG:3857 --scale 30
+        geedim composite -i LANDSAT/LE07/C02/T1_L2/LE07_173083_20100203 -i LANDSAT/LE07/C02/T1_L2/LE07_173083_20100219 download --bbox 22 -33.1 22.1 -33 --crs EPSG:3857 --scale 30
 
     Create and download a composite of a year of GEDI canopy height data, by chaining with ``search``::
 
-        $ geedim search -c LARSE/GEDI/GEDI02_A_002_MONTHLY -s 2021-01-01 -e 2022-01-01 --bbox 23 -34 23.1 -33.9 --fill-portion 0.1 composite -cm mosaic download --crs EPSG:3857 --scale 25
+        geedim search -c LARSE/GEDI/GEDI02_A_002_MONTHLY -s 2021-01-01 -e 2022-01-01 --bbox 23 -34 23.1 -33.9 --fill-portion 0.1 composite -cm mosaic download --crs EPSG:3857 --scale 25
 
     Create and download a cloud/shadow-free composite of Sentinel-2 SR images, by chaining with ``search``::
 
-        $ geedim search -c sentinel2-sr -s 2021-01-12 -e 2021-01-23 --bbox 23 -33.5 23.1 -33.4 composite -cm q-mosaic download --crs EPSG:3857 --scale 10
+        geedim search -c s2-sr -s 2021-01-12 -e 2021-01-23 --bbox 23 -33.5 23.1 -33.4 composite -cm q-mosaic download --crs EPSG:3857 --scale 10
     """
     # @formatter:on
 
