@@ -22,8 +22,6 @@ from typing import Dict, List, Union
 
 import ee
 import tabulate
-from tabulate import TableFormat, Line, DataRow
-
 from geedim import schema, medoid
 from geedim.download import BaseImage
 from geedim.enums import ResamplingMethod, CompositeMethod
@@ -31,6 +29,7 @@ from geedim.errors import UnfilteredError, InputImageError
 from geedim.mask import MaskedImage, class_from_id
 from geedim.stac import StacCatalog, StacItem
 from geedim.utils import split_id, resample
+from tabulate import TableFormat, Line, DataRow
 
 logger = logging.getLogger(__name__)
 tabulate.MIN_PADDING = 0
@@ -46,7 +45,7 @@ _table_fmt = TableFormat(
     datarow=DataRow("", " ", ""),
     padding=0,
     with_header_hide=["lineabove", "linebelow"]
-) # yapf: disable
+)  # yapf: disable
 
 
 def compatible_collections(names: List[str]) -> bool:
@@ -70,6 +69,7 @@ def compatible_collections(names: List[str]) -> bool:
         name_matches.append(name_match)
     return all(name_matches)
 
+
 def parse_date(date: Union[datetime, str], var_name=None) -> datetime:
     """ Convert a string to a datetime, raising an exception if it is in the wrong format. """
     var_name = var_name or 'date'
@@ -80,6 +80,7 @@ def parse_date(date: Union[datetime, str], var_name=None) -> datetime:
             raise ValueError(f'{var_name} should be a datetime instance or a string with format: "%Y-%m-%d"')
     return date
 
+
 class MaskedCollection:
 
     def __init__(self, ee_collection: ee.ImageCollection):
@@ -349,10 +350,6 @@ class MaskedCollection:
                 date_dist = ee.Number(ee_image.get('system:time_start')).subtract(ee.Date(date).millis()).abs()
                 ee_image = ee_image.set('DATE_DIST', date_dist)
 
-            # TODO: there is a design flaw here, if composite() is called >1x, but with different kwargs,
-            #  only the first kwargs are applied. similarly if composite is called on a searched collection,
-            #  only the search kwargs get applied.  this was done so that composite images could be wrapped in
-            #  MaskedImage w/o trying to find the masks again.  urgh.
             gd_image = self.image_type(ee_image, **kwargs)
             if region and (method in [CompositeMethod.mosaic, CompositeMethod.q_mosaic]):
                 gd_image._set_region_stats(region=region, scale=self._stats_scale)
@@ -439,8 +436,8 @@ class MaskedCollection:
 
     def composite(
         self, method: Union[CompositeMethod, str] = None, mask: bool = True,
-        resampling: Union[ResamplingMethod, str] = None, date: Union[datetime, str] = None,
-        region: dict = None, **kwargs
+        resampling: Union[ResamplingMethod, str] = None, date: Union[datetime, str] = None, region: dict = None,
+        **kwargs
     ) -> MaskedImage:
         """
         Create a composite image from the encapsulated image collection.
@@ -514,7 +511,6 @@ class MaskedCollection:
         comp_image = comp_image.set('INPUT_IMAGES', 'TABLE:\n' + props_str)
 
         # construct an ID for the composite
-        # TODO: these dates are being shifted from capture dates, something with time zone is confused
         dates = [datetime.utcfromtimestamp(item['system:time_start'] / 1000) for item in props.values()]
         start_date = min(dates).strftime('%Y_%m_%d')
         end_date = max(dates).strftime('%Y_%m_%d')
