@@ -29,17 +29,16 @@ from typing import Tuple, Dict, List, Union, Iterator
 import ee
 import numpy as np
 import rasterio as rio
-from rasterio.crs import CRS
-from rasterio.enums import Resampling as RioResampling
-from rasterio.windows import Window
-from tqdm.auto import tqdm
-from tqdm import TqdmWarning
-from tqdm.contrib.logging import logging_redirect_tqdm
-
+from geedim import utils
 from geedim.enums import ResamplingMethod
 from geedim.stac import StacCatalog, StacItem
 from geedim.tile import Tile
-from geedim.utils import Spinner, resample, retry_session
+from rasterio.crs import CRS
+from rasterio.enums import Resampling as RioResampling
+from rasterio.windows import Window
+from tqdm import TqdmWarning
+from tqdm.auto import tqdm
+from tqdm.contrib.logging import logging_redirect_tqdm
 
 logger = logging.getLogger(__name__)
 
@@ -291,9 +290,58 @@ class BaseImage:
             band_props = [dict(name=bid) for bid in band_ids]
         return band_props
 
+    @staticmethod
+    def _scale_offset(ee_image: ee.Image, band_properties: List[Dict]) -> ee.Image:
+        """
+        Apply any STAC band scales and offsets to an EE image.
+
+        Applying STAC scales and offsets will convert pixel values from representative integer ranges to the floating
+        point ranges of physical quantities (e.g. surface reflectance in the range 0-1).
+
+        Parameters
+        ----------
+        ee_image: ee.Image
+            The EE image to scale and offset.
+        band_properties: list(dict)
+            A list of dictionaries specifying band names and corresponding scale and or offset values e.g.
+            :attr:`BaseImage.band_properties`.
+
+        Returns
+        -------
+        ee.Image
+            The scaled and offset image, with the same bands as ``ee_image``, and in the same order.
+        """
+        if band_properties is None:
+            logger.warning('Cannot scale and offset this image, there is no STAC band information.')
+            return ee_image
+
+        # make band scale and offset dicts
+        scale_dict = {bp['name']: bp['scale'] if 'scale' in bp else 1. for bp in band_properties}
+        offset_dict = {bp['name']: bp['offset'] if 'offset' in bp else 0. for bp in band_properties}
+
+        if all([s == 1 for s in scale_dict.values()]) and all([o == 0 for o in offset_dict.values()]):
+            # all scales==1 and all offsets==0
+            return ee_image
+
+        adj_bands = ee_image.bandNames().filter(ee.Filter.inList('item', list(scale_dict.keys())))
+        non_adj_bands = ee_image.bandNames().removeAll(adj_bands)
+
+        # apply the scales and offsets
+        scale_im = ee.Dictionary(scale_dict).toImage().select(adj_bands)
+        offset_im = ee.Dictionary(offset_dict).toImage().select(adj_bands)
+        adj_im = ee_image.select(adj_bands).multiply(scale_im).add(offset_im)
+
+        # Typically, `band_properties` will contain items for every band, but there may be cases where there
+        # are additional image bands in `ee_image` not in `band_properties`. Here, these additional bands are added
+        # back to the adjusted image.
+        adj_im = adj_im.addBands(ee_image.select(non_adj_bands))
+        adj_im = adj_im.select(ee_image.bandNames())  # keep bands in original order
+        # copy original ee_image properties and return
+        return ee.Image(adj_im.copyProperties(ee_image, ee_image.propertyNames()))
+
     def _prepare_for_export(
         self, region: Dict = None, crs: str = None, scale: float = None,
-        resampling: ResamplingMethod = _default_resampling, dtype: str = None
+        resampling: ResamplingMethod = _default_resampling, dtype: str = None, scale_offset: bool = False
     ) -> 'BaseImage':
         """
         Prepare the encapsulated image for export/download.  Will reproject, resample, clip and convert the image
@@ -314,6 +362,8 @@ class BaseImage:
         dtype: str, optional
            Convert to this data type (`uint8`, `int8`, `uint16`, `int16`, `uint32`, `int32`, `float32`
            or `float64`). Defaults to auto select a minimal type that can represent the range of pixel values.
+        scale_offset: bool, optional
+            Whether to apply any EE band scales and offsets to the image.
 
         Returns
         -------
@@ -348,17 +398,23 @@ class BaseImage:
                 'https://issuetracker.google.com/issues/194561313'
             )
 
+        ee_image = self.ee_image
+        if scale_offset:
+            ee_image = self._scale_offset(ee_image, self.band_properties)
+            im_dtype = 'float64'
+        else:
+            im_dtype = self.dtype
+
         resampling = ResamplingMethod(resampling)
-        ee_image = self._ee_image
         if resampling != self._default_resampling:
             if not self.has_fixed_projection:
                 raise ValueError(
                     'This image has no fixed projection and cannot be resampled.  If this image is a composite, '
                     'you can resample the images used to create the composite.'
                 )
-            ee_image = resample(ee_image, resampling)
+            ee_image = utils.resample(ee_image, resampling)
 
-        ee_image = self._convert_dtype(ee_image, dtype=dtype or self.dtype)
+        ee_image = self._convert_dtype(ee_image, dtype=dtype or im_dtype)
         # TODO: Specify `crs_transform` and `dimensions` (as in tile), so that everything stays on the source grid
         #  where possible i.e. where the export CRS and scale are the same as the source.
         export_args = dict(region=region, crs=crs, scale=scale, fileFormat='GeoTIFF', filePerBand=False)
@@ -384,7 +440,7 @@ class BaseImage:
             int16=np.iinfo('int16').min,
             uint32=0,
             int32=np.iinfo('int32').min
-        ) # yapf: disable
+        )  # yapf: disable
         nodata = nodata_dict[exp_image.dtype] if set_nodata else None
         profile = dict(
             driver='GTiff', dtype=exp_image.dtype, nodata=nodata, width=exp_image.shape[1], height=exp_image.shape[0],
@@ -396,7 +452,7 @@ class BaseImage:
     @staticmethod
     def _get_tile_shape(
         exp_image: 'BaseImage', max_download_size: int = 32 << 20, max_grid_dimension: int = 10000
-    ) -> (Tuple[int, int], int): # yapf: disable
+    ) -> (Tuple[int, int], int):  # yapf: disable
         """
         Return a tile shape and number of tiles for a given BaseImage, such that the tile shape satisfies GEE
         download limits, and is 'square-ish'.
@@ -446,14 +502,30 @@ class BaseImage:
         if dataset.closed:
             raise IOError('Image dataset is closed')
 
-        dataset.update_tags(**self.properties)
-        if self._stac:
-            dataset.update_tags(TERMS_OF_USE=self._stac.terms)
+        # replace 'system:*' property keys with 'system-*', and remove footprint if its there
+        properties = {k.replace(':', '-'):v for k, v in self.properties.items()}
+        if 'system-footprint' in properties:
+            properties.pop('system-footprint')
+        dataset.update_tags(**properties)
+
+        if self._stac and self._stac.license:
+            dataset.update_tags(LICENSE=self._stac.license)
+
+        def clean_text(text, width=80) -> str:
+            """ Return a shortened tidied string. """
+            if not isinstance(text, str):
+                return text
+            text = text.split('.')[0] if len(text) > width else text
+            text = text.strip()
+            text = '-\n' + text if len(text) > width else text
+            return text
+
         # populate band metadata
         for band_i, band_dict in enumerate(self.band_properties):
+            clean_band_dict = {k.replace(':', '-'): clean_text(v) for k, v in band_dict.items()}
             if 'name' in band_dict:
-                dataset.set_band_description(band_i + 1, band_dict['name'])
-            dataset.update_tags(band_i + 1, **band_dict)
+                dataset.set_band_description(band_i + 1, clean_band_dict['name'])
+            dataset.update_tags(band_i + 1, **clean_band_dict)
 
     @staticmethod
     def _tiles(exp_image: 'BaseImage', tile_shape: Tuple[int, int] = None) -> Iterator[Tile]:
@@ -507,7 +579,7 @@ class BaseImage:
         label = label if (len(label) < BaseImage._desc_width) else f'*{label[-BaseImage._desc_width:]}'
 
         # poll EE until the export preparation is complete
-        with Spinner(label=f'Preparing {label}: ', leave='done'):
+        with utils.Spinner(label=f'Preparing {label}: ', leave='done'):
             while 'progress' not in status['metadata']:
                 time.sleep(5 * pause)
                 status = ee.data.getOperation(task.name)
@@ -550,6 +622,8 @@ class BaseImage:
         dtype: str, optional
            Convert to this data type (`uint8`, `int8`, `uint16`, `int16`, `uint32`, `int32`, `float32`
            or `float64`). Defaults to auto select a minimal type that can represent the range of pixel values.
+        scale_offset: bool, optional
+            Whether to apply any EE band scales and offsets to the image.
 
         Returns
         -------
@@ -601,6 +675,8 @@ class BaseImage:
         dtype: str, optional
             Convert to this data type (`uint8`, `int8`, `uint16`, `int16`, `uint32`, `int32`, `float32`
             or `float64`).  Defaults to auto select a minimum size type that can represent the range of pixel values.
+        scale_offset: bool, optional
+            Whether to apply any EE band scales and offsets to the image.
         """
 
         max_threads = num_threads or min(32, (os.cpu_count() or 1) + 4)
@@ -646,7 +722,7 @@ class BaseImage:
             desc=desc, total=raw_download_size, bar_format=bar_format, dynamic_ncols=True, unit_scale=True, unit='B'
         )
 
-        session = retry_session(5)
+        session = utils.retry_session(5)
         warnings.filterwarnings('ignore', category=TqdmWarning)
         redir_tqdm = logging_redirect_tqdm([logging.getLogger(__package__)])  # redirect logging through tqdm
         out_ds = rio.open(filename, 'w', **profile)  # create output geotiff
