@@ -15,6 +15,7 @@
 """
 
 import itertools
+import json
 import logging
 import os
 import pathlib
@@ -22,18 +23,16 @@ import sys
 import time
 from threading import Thread
 from typing import Tuple
-import json
 
 import ee
 import rasterio as rio
 import requests
+from geedim.enums import ResamplingMethod
 from rasterio.warp import transform_geom
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
 from tqdm.auto import tqdm
 
-from geedim.enums import ResamplingMethod
-
 if '__file__' in globals():
     root_path = pathlib.Path(__file__).absolute().parents[1]
 else:
@@ -262,13 +261,14 @@ def resample(ee_image: ee.Image, method: ResamplingMethod) -> ee.Image:
     ee_image: ee.Image
         Resampled image.
     """
+    # TODO : use STAC to only resample continuous qty type bands
     method = ResamplingMethod(method)
     if method == ResamplingMethod.near:
         return ee_image
 
     # resample the image, if it has a fixed projection
     proj = ee_image.select(0).projection()
-    has_fixed_proj = proj.crs().compareTo('EPSG:4326').neq(0).Or(proj.nominalScale().neq(111319.49079327357))
+    has_fixed_proj = proj.crs().compareTo('EPSG:4326').neq(0).Or(proj.nominalScale().toInt64().neq(111319))
 
     def _resample(ee_image: ee.Image) -> ee.Image:
         """ Resample the given image, allowing for additional 'average' method. """
